from typing import Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.thread_filter_feedback_type_0 import ThreadFilterFeedbackType0
from ..types import UNSET, Unset

T = TypeVar("T", bound="ThreadFilter")


@_attrs_define
class ThreadFilter:
    """
    Attributes:
        feedback (Union[None, ThreadFilterFeedbackType0, Unset]):
        user_id (Union[None, Unset, str]):
        search (Union[None, Unset, str]):
    """

    feedback: Union[None, ThreadFilterFeedbackType0, Unset] = UNSET
    user_id: Union[None, Unset, str] = UNSET
    search: Union[None, Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        feedback: Union[None, Unset, int]
        if isinstance(self.feedback, Unset):
            feedback = UNSET
        elif isinstance(self.feedback, ThreadFilterFeedbackType0):
            feedback = self.feedback.value
        else:
            feedback = self.feedback

        user_id: Union[None, Unset, str]
        if isinstance(self.user_id, Unset):
            user_id = UNSET
        else:
            user_id = self.user_id

        search: Union[None, Unset, str]
        if isinstance(self.search, Unset):
            search = UNSET
        else:
            search = self.search

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if feedback is not UNSET:
            field_dict["feedback"] = feedback
        if user_id is not UNSET:
            field_dict["userId"] = user_id
        if search is not UNSET:
            field_dict["search"] = search

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()

        def _parse_feedback(data: object) -> Union[None, ThreadFilterFeedbackType0, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, int):
                    raise TypeError()
                feedback_type_0 = ThreadFilterFeedbackType0(data)

                return feedback_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, ThreadFilterFeedbackType0, Unset], data)

        feedback = _parse_feedback(d.pop("feedback", UNSET))

        def _parse_user_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        user_id = _parse_user_id(d.pop("userId", UNSET))

        def _parse_search(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        search = _parse_search(d.pop("search", UNSET))

        thread_filter = cls(
            feedback=feedback,
            user_id=user_id,
            search=search,
        )

        thread_filter.additional_properties = d
        return thread_filter

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="BlogPostItem")


@_attrs_define
class BlogPostItem:
    """
    Attributes:
        slug (str):
        site_id (str):
        id (str):
        title (Union[None, Unset, str]):
        created_at (Union[Unset, datetime.datetime]):
        updated_at (Union[Unset, datetime.datetime]):
        author (Union[None, Unset, str]):
    """

    slug: str
    site_id: str
    id: str
    title: Union[None, Unset, str] = UNSET
    created_at: Union[Unset, datetime.datetime] = UNSET
    updated_at: Union[Unset, datetime.datetime] = UNSET
    author: Union[None, Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        slug = self.slug

        site_id = self.site_id

        id = self.id

        title: Union[None, Unset, str]
        if isinstance(self.title, Unset):
            title = UNSET
        else:
            title = self.title

        created_at: Union[Unset, str] = UNSET
        if not isinstance(self.created_at, Unset):
            created_at = self.created_at.isoformat()

        updated_at: Union[Unset, str] = UNSET
        if not isinstance(self.updated_at, Unset):
            updated_at = self.updated_at.isoformat()

        author: Union[None, Unset, str]
        if isinstance(self.author, Unset):
            author = UNSET
        else:
            author = self.author

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "slug": slug,
                "site_id": site_id,
                "id": id,
            }
        )
        if title is not UNSET:
            field_dict["title"] = title
        if created_at is not UNSET:
            field_dict["created_at"] = created_at
        if updated_at is not UNSET:
            field_dict["updated_at"] = updated_at
        if author is not UNSET:
            field_dict["author"] = author

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        slug = d.pop("slug")

        site_id = d.pop("site_id")

        id = d.pop("id")

        def _parse_title(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        title = _parse_title(d.pop("title", UNSET))

        _created_at = d.pop("created_at", UNSET)
        created_at: Union[Unset, datetime.datetime]
        if isinstance(_created_at, Unset):
            created_at = UNSET
        else:
            created_at = isoparse(_created_at)

        _updated_at = d.pop("updated_at", UNSET)
        updated_at: Union[Unset, datetime.datetime]
        if isinstance(_updated_at, Unset):
            updated_at = UNSET
        else:
            updated_at = isoparse(_updated_at)

        def _parse_author(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        author = _parse_author(d.pop("author", UNSET))

        blog_post_item = cls(
            slug=slug,
            site_id=site_id,
            id=id,
            title=title,
            created_at=created_at,
            updated_at=updated_at,
            author=author,
        )

        blog_post_item.additional_properties = d
        return blog_post_item

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

if TYPE_CHECKING:
    from ..models.pagination import Pagination
    from ..models.thread_filter import ThreadFilter


T = TypeVar("T", bound="GetThreadsRequest")


@_attrs_define
class GetThreadsRequest:
    """
    Attributes:
        pagination (Pagination):
        filter_ (ThreadFilter):
    """

    pagination: "Pagination"
    filter_: "ThreadFilter"
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        pagination = self.pagination.to_dict()

        filter_ = self.filter_.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "pagination": pagination,
                "filter": filter_,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.pagination import Pagination
        from ..models.thread_filter import ThreadFilter

        d = src_dict.copy()
        pagination = Pagination.from_dict(d.pop("pagination"))

        filter_ = ThreadFilter.from_dict(d.pop("filter"))

        get_threads_request = cls(
            pagination=pagination,
            filter_=filter_,
        )

        get_threads_request.additional_properties = d
        return get_threads_request

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.page_meta_author import PageMetaAuthor


T = TypeVar("T", bound="PageMetaResponse")


@_attrs_define
class PageMetaResponse:
    """对应前端页面的 page meta 信息

    Attributes:
        title (Union[None, Unset, str]):  Default: ''.
        metadata_base (Union[Unset, str]):  Default: ''.
        description (Union[Unset, str]):  Default: ''.
        keywords (Union[Unset, List[str]]):
        authors (Union[Unset, List['PageMetaAuthor']]):
        creator (Union[Unset, str]):  Default: ''.
        manifest (Union[Unset, str]):  Default: ''.
    """

    title: Union[None, Unset, str] = ""
    metadata_base: Union[Unset, str] = ""
    description: Union[Unset, str] = ""
    keywords: Union[Unset, List[str]] = UNSET
    authors: Union[Unset, List["PageMetaAuthor"]] = UNSET
    creator: Union[Unset, str] = ""
    manifest: Union[Unset, str] = ""
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        title: Union[None, Unset, str]
        if isinstance(self.title, Unset):
            title = UNSET
        else:
            title = self.title

        metadata_base = self.metadata_base

        description = self.description

        keywords: Union[Unset, List[str]] = UNSET
        if not isinstance(self.keywords, Unset):
            keywords = self.keywords

        authors: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.authors, Unset):
            authors = []
            for authors_item_data in self.authors:
                authors_item = authors_item_data.to_dict()
                authors.append(authors_item)

        creator = self.creator

        manifest = self.manifest

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if title is not UNSET:
            field_dict["title"] = title
        if metadata_base is not UNSET:
            field_dict["metadataBase"] = metadata_base
        if description is not UNSET:
            field_dict["description"] = description
        if keywords is not UNSET:
            field_dict["keywords"] = keywords
        if authors is not UNSET:
            field_dict["authors"] = authors
        if creator is not UNSET:
            field_dict["creator"] = creator
        if manifest is not UNSET:
            field_dict["manifest"] = manifest

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.page_meta_author import PageMetaAuthor

        d = src_dict.copy()

        def _parse_title(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        title = _parse_title(d.pop("title", UNSET))

        metadata_base = d.pop("metadataBase", UNSET)

        description = d.pop("description", UNSET)

        keywords = cast(List[str], d.pop("keywords", UNSET))

        authors = []
        _authors = d.pop("authors", UNSET)
        for authors_item_data in _authors or []:
            authors_item = PageMetaAuthor.from_dict(authors_item_data)

            authors.append(authors_item)

        creator = d.pop("creator", UNSET)

        manifest = d.pop("manifest", UNSET)

        page_meta_response = cls(
            title=title,
            metadata_base=metadata_base,
            description=description,
            keywords=keywords,
            authors=authors,
            creator=creator,
            manifest=manifest,
        )

        page_meta_response.additional_properties = d
        return page_meta_response

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
